@@ -403,6 +403,7 @@ DataInput::DataInput()
    editItemAction(new Lum::Model::Action()),
 
    foodSearch(new Lum::Model::String(L"")),
+   averageDiff(new Lum::Model::String(L"")),
    summary(new Lum::Model::String(L"")),
    time(new Lum::Model::Time()),
    foods(new Lum::Model::ListTable(3)),
@@ -536,13 +537,6 @@ void DataInput::CalcSize()
   dateSelect->SetModel(date);
   ds->Add(dateSelect);
 
-  /*
-  button=new Lum::Button(L"_*");
-  button->SetFlex(true,false);
-  button->RequestFocus();
-  button->SetModel(todayAction);
-  horiz->Add(button);*/
-
   ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
 
   button=new Lum::Button(L"_>");
@@ -550,16 +544,23 @@ void DataInput::CalcSize()
   button->SetModel(nextDayAction);
   ds->Add(button);
 
-  ds->Add(new Lum::HSpace());
+  ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
 
   text=new Lum::TextValue();
   text->SetFlex(true,false);
   text->SetAlignment(Lum::TextValue::right);
-  text->SetMinWidth(Lum::Base::Size::stdCharWidth,8);
-  text->SetModel(summary);
+  text->SetMinWidth(Lum::Base::Size::stdCharWidth,5);
+  text->SetModel(averageDiff);
   ds->Add(text);
 
-  ds->Add(new Lum::HSpace(true));
+  ds->Add(new Lum::HSpace(Lum::Space::sizeSmall));
+
+  text=new Lum::TextValue();
+  text->SetFlex(true,false);
+  text->SetAlignment(Lum::TextValue::right);
+  text->SetMinWidth(Lum::Base::Size::stdCharWidth,9);
+  text->SetModel(summary);
+  ds->Add(text);
 
   // Entries table
 
@@ -683,7 +684,6 @@ void DataInput::UpdateSummary()
 
   Day *day=data.GetDay(date->Get());
 
-
   if (day!=NULL) {
     for (std::list<Entry>::iterator iter=day->entries.begin(); iter!=day->entries.end(); ++iter) {
       if (!iter->item.empty()) {
@@ -702,6 +702,52 @@ void DataInput::UpdateSummary()
   summary->Set(Lum::Base::NumberToWString(current)+
                L"/"+
                Lum::Base::NumberToWString(((int)maxValue->Get())/10-current));
+
+  Lum::Base::Calendar d=date->Get();
+  size_t weightLastWeek=0;
+  size_t weightLastWeekCount=0;
+  size_t weightPriorWeek=0;
+  size_t weightPriorWeekCount=0;
+
+  for (size_t i=1; i<=7; i++) {
+    Day *day=data.GetDay(d);
+
+    if (day!=NULL) {
+      for (std::list<Entry>::iterator iter=day->entries.begin(); iter!=day->entries.end(); ++iter) {
+        if (iter->item.empty()) {
+          weightLastWeek+=iter->amount;
+          weightLastWeekCount++;
+        }
+      }
+    }
+
+    d.AddDays(-1);
+  }
+
+  for (size_t i=1; i<=7; i++) {
+    Day *day=data.GetDay(d);
+
+    if (day!=NULL) {
+      for (std::list<Entry>::iterator iter=day->entries.begin(); iter!=day->entries.end(); ++iter) {
+        if (iter->item.empty()) {
+          weightPriorWeek+=iter->amount;
+          weightPriorWeekCount++;
+        }
+      }
+    }
+
+    d.AddDays(-1);
+  }
+
+  if (weightLastWeekCount==0 || weightPriorWeekCount==0) {
+    averageDiff->Set(L"?");
+  }
+  else {
+    weightLastWeek=weightLastWeek/weightLastWeekCount;
+    weightPriorWeek=weightPriorWeek/weightPriorWeekCount;
+
+    averageDiff->Set(AmountToString(weightLastWeek-weightPriorWeek));
+  }
 }
 
 void DataInput::AddFood()
@@ -1087,4 +1133,5 @@ void DataInput::InitializeGUI()
 {
   UpdateEntries();
   UpdateFoods();
+  UpdateSummary();
 }
